@@ -22,9 +22,9 @@ class StationGroupsManager(ManagerMix):
 
         return StationGroup(**content, client=self._client)
 
-    def create_station_group(self, code, name, description):
+    def create_station_group(self, code, name=None, description=None):
         out = {"name": name,
-                "code": code,
+               "code": code,
                "description": description}
         result = self.post("station-groups", json.dumps(out))
         if result.status_code != 200:
