@@ -1,5 +1,5 @@
 class ElementContext:
-    def __init__(self, id: int, elementId: int = None, timeStepId: int = None, levelId: int = None, code: str = None, aggregation: str = None, unit: str = None, client=None):
+    def __init__(self, id: int, elementId: int = None, timeStepId: int = None, code: str = None, aggregation: str = None, unit: str = None, levelId: int = None, client=None):
         self.unit = unit
         self.aggregation = aggregation
         self.levelId = levelId
@@ -12,6 +12,10 @@ class ElementContext:
 
         self.__load_element()
         self.__load_time_step()
+        if self.code.count("_") == 3:
+            self.__load_level()
+        else:
+            self.level = None
 
 
     @property
@@ -22,4 +26,8 @@ class ElementContext:
         self.element = self._client._elements_manager.element("id:"+str(self.elementId))
 
     def __load_time_step(self):
-        self.time_step = self._client._time_steps_manager.time_step_by_id(self.timeStepId)
\ No newline at end of file
+        self.time_step = self._client._time_steps_manager.time_step_by_id(self.timeStepId)
+
+    def __load_level(self):
+        if self.levelId is not None:
+            self.level = self._client._levels_manager.level_by_id(self.levelId)
\ No newline at end of file
